Skip to main contentModule auth_api
Source - CallbackError
- struct for typed errors of method
callback - GetMeError
- struct for typed errors of method
get_me - LoginError
- struct for typed errors of method
login - LogoutError
- struct for typed errors of method
logout
- callback
- This is the callback route for the OAuth provider, it should not be called directly. Redirects to browser with set-cookie header.
- get_me
- Get the user corresponding to your current auth credentials.
- login
- This will redirect you to the OAuth provider for authentication with email/pass, SSO, Google, Github, etc.
- logout
- Invalidate your current auth credential stored typically stored in a cookie. This does not invalidate your API key.