update_topic

Function update_topic 

pub async fn update_topic(
    configuration: &Configuration,
    tr_dataset: &str,
    update_topic_req_payload: UpdateTopicReqPayload,
) -> Result<(), Error<UpdateTopicError>>
Update an existing chat topic. Currently, only the name of the topic can be updated. Auth’ed user or api key must have an admin or owner role for the specified dataset’s organization.