pub struct CreateSingleChunkGroupReqPayload {
pub description: Option<Option<String>>,
pub metadata: Option<Option<Value>>,
pub name: Option<Option<String>>,
pub tag_set: Option<Option<Vec<String>>>,
pub tracking_id: Option<Option<String>>,
pub upsert_by_tracking_id: Option<Option<bool>>,
}Fields
description: Option<Option<String>>Description to assign to the chunk_group. Convenience field for you to avoid having to remember what the group is for.
metadata: Option<Option<Value>>Optional metadata to assign to the chunk_group. This is a JSON object that can store any additional information you want to associate with the chunks inside of the chunk_group.
name: Option<Option<String>>Name to assign to the chunk_group. Does not need to be unique.
tag_set: Option<Option<Vec<String>>>Optional tags to assign to the chunk_group. This is a list of strings that can be used to categorize the chunks inside the chunk_group.
tracking_id: Option<Option<String>>Optional tracking id to assign to the chunk_group. This is a unique identifier for the chunk_group.
upsert_by_tracking_id: Option<Option<bool>>Upsert when a chunk_group with the same tracking_id exists. By default this is false, and the request will fail if a chunk_group with the same tracking_id exists. If this is true, the chunk_group will be updated if a chunk_group with the same tracking_id exists.
Implementations