pub struct CreateTopicReqPayload {
pub first_user_message: Option<Option<String>>,
pub name: Option<Option<String>>,
pub owner_id: String,
}Fields
first_user_message: Option<Option<String>>The first message which will belong to the topic. The topic name is generated based on this message similar to how it works in the OpenAI chat UX if a name is not explicitly provided on the name request body key.
name: Option<Option<String>>The name of the topic. If this is not provided, the topic name is generated from the first_user_message.
owner_id: StringThe owner_id of the topic. This is typically a browser fingerprint or your user’s id. It is used to group topics together for a user.
Implementations
Sourceimpl CreateTopicReqPayload
impl CreateTopicReqPayload
pub fn new(owner_id: String) -> CreateTopicReqPayload