pub struct EditMessageReqPayload {
pub concat_user_messages_query: Option<Option<bool>>,
pub filters: Option<Option<Box<ChunkFilter>>>,
pub highlight_options: Option<Option<Box<HighlightOptions>>>,
pub llm_options: Option<Option<Box<LlmOptions>>>,
pub message_sort_order: i32,
pub new_message_content: String,
pub page_size: Option<Option<i64>>,
pub score_threshold: Option<Option<f32>>,
pub search_query: Option<Option<String>>,
pub search_type: Option<Option<SearchMethod>>,
pub topic_id: Uuid,
pub user_id: Option<Option<String>>,
}Fields
concat_user_messages_query: Option<Option<bool>>If concat user messages query is set to true, all of the user messages in the topic will be concatenated together and used as the search query. If not specified, this defaults to false. Default is false.
filters: Option<Option<Box<ChunkFilter>>>highlight_options: Option<Option<Box<HighlightOptions>>>llm_options: Option<Option<Box<LlmOptions>>>message_sort_order: i32The sort order of the message to edit.
new_message_content: StringThe new content of the message to replace the old content with.
page_size: Option<Option<i64>>Page size is the number of chunks to fetch during RAG. If 0, then no search will be performed. If specified, this will override the N retrievals to include in the dataset configuration. Default is None.
score_threshold: Option<Option<f32>>Set score_threshold to a float to filter out chunks with a score below the threshold. This threshold applies before weight and bias modifications. If not specified, this defaults to 0.0.
search_query: Option<Option<String>>Query is the search query. This can be any string. The search_query will be used to create a dense embedding vector and/or sparse vector which will be used to find the result set. If not specified, will default to the last user message or HyDE if HyDE is enabled in the dataset configuration. Default is None.
search_type: Option<Option<SearchMethod>>topic_id: UuidThe id of the topic to edit the message at the given sort order for.
user_id: Option<Option<String>>The user_id is the id of the user who is making the request. This is used to track user interactions with the RAG results.
Implementations