QdrantSortBy

Enum QdrantSortBy 

pub enum QdrantSortBy {
    SortByField(Box<SortByField>),
    SortBySearchType(Box<SortBySearchType>),
}
QdrantSortBy : Sort by lets you specify a method to sort the results by. If not specified, this defaults to the score of the chunks. If specified, this can be any key in the chunk metadata. This key must be a numeric value within the payload. Sort by lets you specify a method to sort the results by. If not specified, this defaults to the score of the chunks. If specified, this can be any key in the chunk metadata. This key must be a numeric value within the payload.

Variants



SortByField(Box<SortByField>)



SortBySearchType(Box<SortBySearchType>)