RecommendGroupsReqPayload

Struct RecommendGroupsReqPayload 

pub struct RecommendGroupsReqPayload {
    pub filters: Option<Option<Box<ChunkFilter>>>,
    pub group_size: Option<Option<i32>>,
    pub limit: Option<Option<i64>>,
    pub negative_group_ids: Option<Option<Vec<Uuid>>>,
    pub negative_group_tracking_ids: Option<Option<Vec<String>>>,
    pub positive_group_ids: Option<Option<Vec<Uuid>>>,
    pub positive_group_tracking_ids: Option<Option<Vec<String>>>,
    pub recommend_type: Option<Option<RecommendType>>,
    pub slim_chunks: Option<Option<bool>>,
    pub strategy: Option<Option<RecommendationStrategy>>,
    pub user_id: Option<Option<String>>,
}

Fields

filters: Option<Option<Box<ChunkFilter>>>group_size: Option<Option<i32>>

The number of chunks to fetch for each group. This is the number of chunks which will be returned in the response for each group. The default is 3. If this is set to a large number, we recommend setting slim_chunks to true to avoid returning the content and chunk_html of the chunks so as to reduce latency due to content download and serialization.

limit: Option<Option<i64>>

The number of groups to return. This is the number of groups which will be returned in the response. The default is 10.

negative_group_ids: Option<Option<Vec<Uuid>>>

The ids of the groups to be used as negative examples for the recommendation. The groups in this array will be used to filter out similar groups.

negative_group_tracking_ids: Option<Option<Vec<String>>>

The ids of the groups to be used as negative examples for the recommendation. The groups in this array will be used to filter out similar groups.

positive_group_ids: Option<Option<Vec<Uuid>>>

The ids of the groups to be used as positive examples for the recommendation. The groups in this array will be used to find similar groups.

positive_group_tracking_ids: Option<Option<Vec<String>>>

The ids of the groups to be used as positive examples for the recommendation. The groups in this array will be used to find similar groups.

recommend_type: Option<Option<RecommendType>>slim_chunks: Option<Option<bool>>

Set slim_chunks to true to avoid returning the content and chunk_html of the chunks. This is useful for when you want to reduce amount of data over the wire for latency improvement (typicall 10-50ms). Default is false.

strategy: Option<Option<RecommendationStrategy>>user_id: Option<Option<String>>

The user_id is the id of the user who is making the request. This is used to track user interactions with the rrecommendation results.

Implementations