Module recommend_type

Module recommend_type 

Enums

RecommendType
RecommendType : The type of recommendation to make. This lets you choose whether to recommend based off of semantic or fulltext similarity. The default is semantic. The type of recommendation to make. This lets you choose whether to recommend based off of semantic or fulltext similarity. The default is semantic.