pub enum RecommendType {
Semantic,
Fulltext,
Bm25,
}Expand description
RecommendType : The type of recommendation to make. This lets you choose whether to recommend based off of semantic or fulltext similarity. The default is semantic.
The type of recommendation to make. This lets you choose whether to recommend based off of semantic or fulltext similarity. The default is semantic.
Variants