pub struct SortByField {
pub direction: Option<Option<SortOrder>>,
pub field: String,
pub prefetch_amount: Option<Option<i64>>,
}Fields
direction: Option<Option<SortOrder>>field: StringField to sort by. This has to be a numeric field with a Qdrant Range index on it. i.e. num_value and timestamp
prefetch_amount: Option<Option<i64>>How many results to pull in before the sort
Implementations
Sourceimpl SortByField
impl SortByField
pub fn new(field: String) -> SortByField