Module sort_options

Module sort_options 

Structs

SortOptions
SortOptions : Sort Options lets you specify different methods to rerank the chunks in the result set. If not specified, this defaults to the score of the chunks.