UpdateChunkGroupReqPayload

Struct UpdateChunkGroupReqPayload 

pub struct UpdateChunkGroupReqPayload {
    pub description: Option<Option<String>>,
    pub group_id: Option<Option<Uuid>>,
    pub metadata: Option<Option<Value>>,
    pub name: Option<Option<String>>,
    pub tag_set: Option<Option<Vec<String>>>,
    pub tracking_id: Option<Option<String>>,
    pub update_chunks: Option<Option<bool>>,
}

Fields

description: Option<Option<String>>

Description to assign to the chunk_group. Convenience field for you to avoid having to remember what the group is for. If not provided, the description will not be updated.

group_id: Option<Option<Uuid>>

Id of the chunk_group to update.

metadata: Option<Option<Value>>

Optional metadata to assign to the chunk_group. This is a JSON object that can store any additional information you want to associate with the chunks inside of the chunk_group.

name: Option<Option<String>>

Name to assign to the chunk_group. Does not need to be unique. If not provided, the name will not be updated.

tag_set: Option<Option<Vec<String>>>

Optional tags to assign to the chunk_group. This is a list of strings that can be used to categorize the chunks inside the chunk_group.

tracking_id: Option<Option<String>>

Tracking Id of the chunk_group to update.

update_chunks: Option<Option<bool>>

Flag to update the chunks in the group. If true, each chunk in the group will be updated by appending the group’s tags to the chunk’s tags. Default is false.

Implementations