pub struct CountChunksReqPayload {
pub filters: Option<Option<Box<ChunkFilter>>>,
pub limit: Option<Option<i64>>,
pub query: Box<QueryTypes>,
pub score_threshold: Option<Option<f32>>,
pub search_type: CountSearchMethod,
pub use_quote_negated_terms: Option<Option<bool>>,
}Fields
filters: Option<Option<Box<ChunkFilter>>>limit: Option<Option<i64>>Set limit to restrict the maximum number of chunks to count. This is useful for when you want to reduce the latency of the count operation. By default the limit will be the number of chunks in the dataset.
query: Box<QueryTypes>score_threshold: Option<Option<f32>>Set score_threshold to a float to filter out chunks with a score below the threshold. This threshold applies before weight and bias modifications. If not specified, this defaults to 0.0.
search_type: CountSearchMethoduse_quote_negated_terms: Option<Option<bool>>If true, quoted and - prefixed words will be parsed from the queries and used as required and negated words respectively. Default is false.
Implementations
Sourceimpl CountChunksReqPayload
impl CountChunksReqPayload
pub fn new( query: QueryTypes, search_type: CountSearchMethod, ) -> CountChunksReqPayload