pub struct SearchOverGroupsReqPayload {Show 13 fields
pub filters: Option<Option<Box<ChunkFilter>>>,
pub get_total_pages: Option<Option<bool>>,
pub group_size: Option<Option<i32>>,
pub highlight_options: Option<Option<Box<HighlightOptions>>>,
pub page: Option<Option<i64>>,
pub page_size: Option<Option<i64>>,
pub query: Box<QueryTypes>,
pub remove_stop_words: Option<Option<bool>>,
pub score_threshold: Option<Option<f32>>,
pub search_type: SearchMethod,
pub slim_chunks: Option<Option<bool>>,
pub use_quote_negated_terms: Option<Option<bool>>,
pub user_id: Option<Option<String>>,
}Fields
filters: Option<Option<Box<ChunkFilter>>>get_total_pages: Option<Option<bool>>Get total page count for the query accounting for the applied filters. Defaults to false, but can be set to true when the latency penalty is acceptable (typically 50-200ms).
group_size: Option<Option<i32>>Group_size is the number of chunks to fetch for each group. The default is 3. If a group has less than group_size chunks, all chunks will be returned. If this is set to a large number, we recommend setting slim_chunks to true to avoid returning the content and chunk_html of the chunks so as to lower the amount of time required for content download and serialization.
highlight_options: Option<Option<Box<HighlightOptions>>>page: Option<Option<i64>>Page of group results to fetch. Page is 1-indexed.
page_size: Option<Option<i64>>Page size is the number of group results to fetch. The default is 10.
query: Box<QueryTypes>remove_stop_words: Option<Option<bool>>If true, stop words (specified in server/src/stop-words.txt in the git repo) will be removed. Queries that are entirely stop words will be preserved.
score_threshold: Option<Option<f32>>Set score_threshold to a float to filter out chunks with a score below the threshold. This threshold applies before weight and bias modifications. If not specified, this defaults to 0.0.
search_type: SearchMethodslim_chunks: Option<Option<bool>>Set slim_chunks to true to avoid returning the content and chunk_html of the chunks. This is useful for when you want to reduce amount of data over the wire for latency improvement (typicall 10-50ms). Default is false.
use_quote_negated_terms: Option<Option<bool>>If true, quoted and - prefixed words will be parsed from the queries and used as required and negated words respectively. Default is false.
user_id: Option<Option<String>>The user_id is the id of the user who is making the request. This is used to track user interactions with the search results.
Implementations
Sourceimpl SearchOverGroupsReqPayload
impl SearchOverGroupsReqPayload
pub fn new( query: QueryTypes, search_type: SearchMethod, ) -> SearchOverGroupsReqPayload